==> hgu133plus2.db_2.2.5.tar.gz: hgu133plus2.db/man/hgu133plus2_dbconn.Rd <==
\name{hgu133plus2_dbconn}

\alias{hgu133plus2_dbconn}
\alias{hgu133plus2_dbfile}
\alias{hgu133plus2_dbschema}
\alias{hgu133plus2_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  hgu133plus2_dbconn()
  hgu133plus2_dbfile()
  hgu133plus2_dbschema(file="", show.indices=FALSE)
  hgu133plus2_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{hgu133plus2_dbconn} returns a connection object to the package
  annotation DB.
  IMPORTANT: Don't call \code{\link[DBI]{dbDisconnect}} on the connection
  object returned by \code{hgu133plus2_dbconn} or you will
  break all the \code{\link[AnnotationDbi]{AnnDbObj}} objects defined in this package!

  \code{hgu133plus2_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{hgu133plus2_dbschema} prints the schema definition of the
  package annotation DB.

  \code{hgu133plus2_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{hgu133plus2_dbconn}: a DBIConnection object representing an open
  connection to the package annotation DB.

  \code{hgu133plus2_dbfile}: a character string with the path to the
  package annotation DB.

  \code{hgu133plus2_dbschema}: none (invisible \code{NULL}).

  \code{hgu133plus2_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI]{dbGetQuery}},
  \code{\link[DBI]{dbConnect}},
  \code{\link[AnnotationDbi]{dbconn}},
  \code{\link[AnnotationDbi]{dbfile}},
  \code{\link[AnnotationDbi]{dbschema}},
  \code{\link[AnnotationDbi]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(hgu133plus2_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by hgu133plus2_dbconn() was created with:
  dbConnect(SQLite(), dbname=hgu133plus2_dbfile(), cache_size=64000, synchronous=0)

  hgu133plus2_dbschema()

  hgu133plus2_dbInfo()
}

\keyword{utilities}
\keyword{datasets}

==> hgu133plus2.db_2.6.3.tar.gz: hgu133plus2.db/man/hgu133plus2_dbconn.Rd <==

\name{hgu133plus2_dbconn}

\alias{hgu133plus2_dbconn}
\alias{hgu133plus2_dbfile}
\alias{hgu133plus2_dbschema}
\alias{hgu133plus2_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  hgu133plus2_dbconn()
  hgu133plus2_dbfile()
  hgu133plus2_dbschema(file="", show.indices=FALSE)
  hgu133plus2_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{hgu133plus2_dbconn} returns a connection object to the
  package annotation DB.  IMPORTANT: Don't call
  \code{\link[DBI:dbConnect]{dbDisconnect}} on the connection object
  returned by \code{hgu133plus2_dbconn} or you will break all the
  \code{\link[AnnotationDbi:AnnDbObj-class]{AnnDbObj}} objects defined
  in this package!

  \code{hgu133plus2_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{hgu133plus2_dbschema} prints the schema definition of the
  package annotation DB.

  \code{hgu133plus2_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{hgu133plus2_dbconn}: a DBIConnection object representing an
  open connection to the package annotation DB.

  \code{hgu133plus2_dbfile}: a character string with the path to the
  package annotation DB.

  \code{hgu133plus2_dbschema}: none (invisible \code{NULL}).

  \code{hgu133plus2_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI:dbSendQuery]{dbGetQuery}},
  \code{\link[DBI:dbConnect]{dbConnect}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbconn}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbfile}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbschema}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(hgu133plus2_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by hgu133plus2_dbconn() was
  ## created with:
  dbConnect(SQLite(), dbname=hgu133plus2_dbfile(), cache_size=64000,
  synchronous=0)

  hgu133plus2_dbschema()

  hgu133plus2_dbInfo()
}

\keyword{utilities}
\keyword{datasets}
